Welcome to BARMPy’s documentation! — BARMPy 0.0.1 documentation

# Welcome to BARMPy’s documentation!

Contents:

- Math
  - Bayesian Additive Regression Models
- BARN
  - NN
  - BARN Class

BARMPy is a Python library to implement Bayesian Additive Regression Networks (BARN, sometimes generalized to BAR*M* for generic Models), a machine learning method to ensemble together small models using Markov Chain Monte Carlo (MCMC) methods. This approach takes much inspiration from Bayesian Additive Regression Trees (BART).

BARN excels at accurately modeling a wide variety of regression problems with equal aplomb. This does come with a cost, as running the MCMC iterations and training neural networks can be computationally intensive. Problems with a thousand data points and ten features can take on the order of a second, but this varies with difficulty of the problem as much as the problem size itself.

# Installation

PyPi packages will be coming soon, but until then, you can install from the repository itself:

    # Current release
    pip install barmpy
    # Latest development version
    git clone git@github.com:dvbuntu/barmpy.git
    pip install -e ./barmpy

# Tutorial

Currently available in BARMPy Repo or precompiled here.

# Links

- Index

- Search Page

- GitHub Repo

- PyPi